@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_UNSUBSCRIBEJOB_H
-#define KIMAP_UNSUBSCRIBEJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -36,4 +35,3 @@ protected:
 
 }
 
-#endif
